@@ -1,13 +1,10 @@
 use fj_math::{Point, Segment};
 
-use crate::{
-    geometry::path::SurfacePath,
-    objects::{Curve, HalfEdge},
-};
+use crate::{geometry::curve::Curve, objects::HalfEdge};
 
 use super::LineSegmentIntersection;
 
-/// The intersection between a [`Curve`] and a [`HalfEdge`]
+/// The intersection between a curve and a [`HalfEdge`]
 #[derive(Clone, Copy, Debug, Eq, PartialEq, Hash, Ord, PartialOrd)]
 pub enum CurveEdgeIntersection {
     /// The curve and edge intersect at a point
@@ -29,17 +26,17 @@ impl CurveEdgeIntersection {
     /// # Panics
     ///
     /// Currently, only intersections between lines and line segments can be
-    /// computed. Panics, if a different type of [`Curve`] or [`HalfEdge`] is
+    /// computed. Panics, if a different type of curve or [`HalfEdge`] is
     /// passed.
     pub fn compute(curve: &Curve, half_edge: &HalfEdge) -> Option<Self> {
-        let curve_as_line = match curve.path() {
-            SurfacePath::Line(line) => line,
+        let curve_as_line = match curve {
+            Curve::Line(line) => line,
             _ => todo!("Curve-edge intersection only supports lines"),
         };
 
         let edge_as_segment = {
-            let edge_curve_as_line = match half_edge.curve().path() {
-                SurfacePath::Line(line) => line,
+            let edge_curve_as_line = match half_edge.curve() {
+                Curve::Line(line) => line,
                 _ => {
                     todo!("Curve-edge intersection only supports line segments")
                 }
@@ -53,7 +50,7 @@ impl CurveEdgeIntersection {
         };
 
         let intersection =
-            LineSegmentIntersection::compute(&curve_as_line, &edge_as_segment)?;
+            LineSegmentIntersection::compute(curve_as_line, &edge_as_segment)?;
 
         let intersection = match intersection {
             LineSegmentIntersection::Point { point_on_line } => Self::Point {
@@ -75,8 +72,9 @@ mod tests {
     use fj_math::Point;
 
     use crate::{
-        builder::{CurveBuilder, HalfEdgeBuilder},
-        partial::{Partial, PartialCurve, PartialHalfEdge, PartialObject},
+        builder::HalfEdgeBuilder,
+        geometry::curve::Curve,
+        partial::{PartialHalfEdge, PartialObject},
         services::Services,
     };
 
@@ -86,19 +84,12 @@ mod tests {
     fn compute_edge_in_front_of_curve_origin() {
         let mut services = Services::new();
 
-        let surface = Partial::from(services.objects.surfaces.xy_plane());
-        let mut curve = PartialCurve {
-            surface: surface.clone(),
-            ..Default::default()
-        };
-        curve.update_as_u_axis();
-        let curve = curve.build(&mut services.objects);
+        let surface = services.objects.surfaces.xy_plane();
+        let curve = Curve::u_axis();
         let half_edge = {
             let mut half_edge = PartialHalfEdge::default();
-            half_edge.update_as_line_segment_from_points(
-                surface,
-                [[1., -1.], [1., 1.]],
-            );
+            half_edge.update_as_line_segment_from_points([[1., -1.], [1., 1.]]);
+            half_edge.infer_vertex_positions_if_necessary(&surface.geometry());
 
             half_edge.build(&mut services.objects)
         };
@@ -117,19 +108,13 @@ mod tests {
     fn compute_edge_behind_curve_origin() {
         let mut services = Services::new();
 
-        let surface = Partial::from(services.objects.surfaces.xy_plane());
-        let mut curve = PartialCurve {
-            surface: surface.clone(),
-            ..Default::default()
-        };
-        curve.update_as_u_axis();
-        let curve = curve.build(&mut services.objects);
+        let surface = services.objects.surfaces.xy_plane();
+        let curve = Curve::u_axis();
         let half_edge = {
             let mut half_edge = PartialHalfEdge::default();
-            half_edge.update_as_line_segment_from_points(
-                surface,
-                [[-1., -1.], [-1., 1.]],
-            );
+            half_edge
+                .update_as_line_segment_from_points([[-1., -1.], [-1., 1.]]);
+            half_edge.infer_vertex_positions_if_necessary(&surface.geometry());
 
             half_edge.build(&mut services.objects)
         };
@@ -148,19 +133,13 @@ mod tests {
     fn compute_edge_parallel_to_curve() {
         let mut services = Services::new();
 
-        let surface = Partial::from(services.objects.surfaces.xy_plane());
-        let mut curve = PartialCurve {
-            surface: surface.clone(),
-            ..Default::default()
-        };
-        curve.update_as_u_axis();
-        let curve = curve.build(&mut services.objects);
+        let surface = services.objects.surfaces.xy_plane();
+        let curve = Curve::u_axis();
         let half_edge = {
             let mut half_edge = PartialHalfEdge::default();
-            half_edge.update_as_line_segment_from_points(
-                surface,
-                [[-1., -1.], [1., -1.]],
-            );
+            half_edge
+                .update_as_line_segment_from_points([[-1., -1.], [1., -1.]]);
+            half_edge.infer_vertex_positions_if_necessary(&surface.geometry());
 
             half_edge.build(&mut services.objects)
         };
@@ -174,19 +153,12 @@ mod tests {
     fn compute_edge_on_curve() {
         let mut services = Services::new();
 
-        let surface = Partial::from(services.objects.surfaces.xy_plane());
-        let mut curve = PartialCurve {
-            surface: surface.clone(),
-            ..Default::default()
-        };
-        curve.update_as_u_axis();
-        let curve = curve.build(&mut services.objects);
+        let surface = services.objects.surfaces.xy_plane();
+        let curve = Curve::u_axis();
         let half_edge = {
             let mut half_edge = PartialHalfEdge::default();
-            half_edge.update_as_line_segment_from_points(
-                surface,
-                [[-1., 0.], [1., 0.]],
-            );
+            half_edge.update_as_line_segment_from_points([[-1., 0.], [1., 0.]]);
+            half_edge.infer_vertex_positions_if_necessary(&surface.geometry());
 
             half_edge.build(&mut services.objects)
         };
