@@ -3,11 +3,11 @@ use std::vec;
 use fj_interop::ext::SliceExt;
 use fj_math::Point;
 
-use crate::objects::{Curve, Face};
+use crate::{geometry::curve::Curve, objects::Face};
 
 use super::CurveEdgeIntersection;
 
-/// The intersections between a [`Curve`] and a [`Face`], in curve coordinates
+/// The intersections between a curve and a [`Face`], in curve coordinates
 #[derive(Clone, Debug, Eq, PartialEq, Hash, Ord, PartialOrd)]
 pub struct CurveFaceIntersection {
     /// The intervals where the curve and face intersect, in curve coordinates
@@ -27,7 +27,7 @@ impl CurveFaceIntersection {
         Self { intervals }
     }
 
-    /// Compute the intersections between a [`Curve`] and a [`Face`]
+    /// Compute the intersection
     pub fn compute(curve: &Curve, face: &Face) -> Self {
         let half_edges = face.all_cycles().flat_map(|cycle| cycle.half_edges());
 
@@ -150,8 +150,9 @@ where
 #[cfg(test)]
 mod tests {
     use crate::{
-        builder::{CurveBuilder, CycleBuilder, FaceBuilder},
-        partial::{Partial, PartialCurve, PartialFace, PartialObject},
+        builder::{CycleBuilder, FaceBuilder},
+        geometry::curve::Curve,
+        partial::{Partial, PartialFace, PartialObject},
         services::Services,
     };
 
@@ -161,14 +162,7 @@ mod tests {
     fn compute() {
         let mut services = Services::new();
 
-        let surface = Partial::from(services.objects.surfaces.xy_plane());
-
-        let mut curve = PartialCurve {
-            surface: surface.clone(),
-            ..Default::default()
-        };
-        curve.update_as_line_from_points([[-3., 0.], [-2., 0.]]);
-        let curve = curve.build(&mut services.objects);
+        let (curve, _) = Curve::line_from_points([[-3., 0.], [-2., 0.]]);
 
         #[rustfmt::skip]
         let exterior = [
@@ -186,8 +180,10 @@ mod tests {
         ];
 
         let face = {
-            let mut face = PartialFace::default();
-            face.exterior.write().surface = surface;
+            let mut face = PartialFace {
+                surface: Partial::from(services.objects.surfaces.xy_plane()),
+                ..Default::default()
+            };
             face.exterior
                 .write()
                 .update_as_polygon_from_points(exterior);
