@@ -1,7 +1,7 @@
 //! Intersection between faces and points in 2D
 
-use fj_interop::ext::ArrayExt;
 use fj_math::Point;
+use itertools::Itertools;
 
 use crate::{
     objects::{Face, HalfEdge, SurfaceVertex},
@@ -34,7 +34,9 @@ impl Intersect for (&Handle<Face>, &Point<2>) {
                 .cloned()
                 .and_then(|edge| (&ray, &edge).intersect());
 
-            for half_edge in cycle.half_edges() {
+            for (half_edge, next_half_edge) in
+                cycle.half_edges().circular_tuple_windows::<(_, _)>()
+            {
                 let hit = (&ray, half_edge).intersect();
 
                 let count_hit = match (hit, previous_hit) {
@@ -49,17 +51,13 @@ impl Intersect for (&Handle<Face>, &Point<2>) {
                         ));
                     }
                     (Some(RaySegmentIntersection::RayStartsOnOnFirstVertex), _) => {
-                        let [vertex, _] = half_edge.boundary().zip_ext(
-                            half_edge.surface_vertices().map(Clone::clone)
-                        );
+                        let vertex = half_edge.start_vertex().clone();
                         return Some(
                             FacePointIntersection::PointIsOnVertex(vertex)
                         );
                     }
                     (Some(RaySegmentIntersection::RayStartsOnSecondVertex), _) => {
-                        let [_, vertex] = half_edge.boundary().zip_ext(
-                            half_edge.surface_vertices().map(Clone::clone)
-                        );
+                        let vertex = next_half_edge.start_vertex().clone();
                         return Some(
                             FacePointIntersection::PointIsOnVertex(vertex)
                         );
@@ -130,12 +128,11 @@ pub enum FacePointIntersection {
     PointIsOnEdge(Handle<HalfEdge>),
 
     /// The point is coincident with a vertex
-    PointIsOnVertex((Point<1>, Handle<SurfaceVertex>)),
+    PointIsOnVertex(Handle<SurfaceVertex>),
 }
 
 #[cfg(test)]
 mod tests {
-    use fj_interop::ext::ArrayExt;
     use fj_math::Point;
     use pretty_assertions::assert_eq;
 
@@ -151,9 +148,10 @@ mod tests {
     fn point_is_outside_face() {
         let mut services = Services::new();
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [0., 0.],
             [1., 1.],
@@ -172,9 +170,10 @@ mod tests {
     fn ray_hits_vertex_while_passing_outside() {
         let mut services = Services::new();
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [0., 0.],
             [2., 1.],
@@ -196,9 +195,10 @@ mod tests {
     fn ray_hits_vertex_at_cycle_seam() {
         let mut services = Services::new();
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [4., 2.],
             [0., 4.],
@@ -220,9 +220,10 @@ mod tests {
     fn ray_hits_vertex_while_staying_inside() {
         let mut services = Services::new();
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [0., 0.],
             [2., 1.],
@@ -245,9 +246,10 @@ mod tests {
     fn ray_hits_parallel_edge_and_leaves_face_at_vertex() {
         let mut services = Services::new();
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [0., 0.],
             [2., 1.],
@@ -270,9 +272,10 @@ mod tests {
     fn ray_hits_parallel_edge_and_does_not_leave_face_there() {
         let mut services = Services::new();
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [0., 0.],
             [2., 1.],
@@ -296,9 +299,10 @@ mod tests {
     fn point_is_coincident_with_edge() {
         let mut services = Services::new();
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [0., 0.],
             [2., 0.],
@@ -315,9 +319,8 @@ mod tests {
             .exterior()
             .half_edges()
             .find(|edge| {
-                let [a, b] = edge.surface_vertices();
-                a.position() == Point::from([0., 0.])
-                    && b.position() == Point::from([2., 0.])
+                let vertex = edge.start_vertex();
+                vertex.position() == Point::from([0., 0.])
             })
             .unwrap();
         assert_eq!(
@@ -330,9 +333,10 @@ mod tests {
     fn point_is_coincident_with_vertex() {
         let mut services = Services::new();
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [0., 0.],
             [1., 0.],
@@ -348,12 +352,8 @@ mod tests {
         let vertex = face
             .exterior()
             .half_edges()
-            .flat_map(|half_edge| {
-                half_edge
-                    .boundary()
-                    .zip_ext(half_edge.surface_vertices().map(Clone::clone))
-            })
-            .find(|(_, surface_vertex)| {
+            .map(|half_edge| half_edge.start_vertex().clone())
+            .find(|surface_vertex| {
                 surface_vertex.position() == Point::from([1., 0.])
             })
             .unwrap();
