@@ -4,7 +4,7 @@ use fj_math::{Plane, Point, Scalar};
 
 use crate::{
     algorithms::intersect::face_point::FacePointIntersection,
-    geometry::path::GlobalPath,
+    geometry::curve::GlobalPath,
     objects::{Face, HalfEdge, SurfaceVertex},
     storage::Handle,
 };
@@ -136,12 +136,11 @@ pub enum RayFaceIntersection {
     RayHitsEdge(Handle<HalfEdge>),
 
     /// The ray hits a vertex
-    RayHitsVertex((Point<1>, Handle<SurfaceVertex>)),
+    RayHitsVertex(Handle<SurfaceVertex>),
 }
 
 #[cfg(test)]
 mod tests {
-    use fj_interop::ext::ArrayExt;
     use fj_math::Point;
 
     use crate::{
@@ -164,9 +163,10 @@ mod tests {
 
         let ray = HorizontalRayToTheRight::from([0., 0., 0.]);
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.yz_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.yz_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [-1., -1.],
             [1., -1.],
@@ -187,9 +187,10 @@ mod tests {
 
         let ray = HorizontalRayToTheRight::from([0., 0., 0.]);
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.yz_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.yz_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [-1., -1.],
             [1., -1.],
@@ -213,9 +214,10 @@ mod tests {
 
         let ray = HorizontalRayToTheRight::from([0., 0., 0.]);
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.yz_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.yz_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [-1., -1.],
             [1., -1.],
@@ -236,9 +238,10 @@ mod tests {
 
         let ray = HorizontalRayToTheRight::from([0., 0., 0.]);
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.yz_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.yz_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [-1., -1.],
             [1., -1.],
@@ -254,9 +257,8 @@ mod tests {
             .exterior()
             .half_edges()
             .find(|edge| {
-                let [a, b] = edge.surface_vertices();
-                a.position() == Point::from([-1., 1.])
-                    && b.position() == Point::from([-1., -1.])
+                let vertex = edge.start_vertex();
+                vertex.position() == Point::from([-1., 1.])
             })
             .unwrap();
         assert_eq!(
@@ -271,9 +273,10 @@ mod tests {
 
         let ray = HorizontalRayToTheRight::from([0., 0., 0.]);
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.yz_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.yz_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [-1., -1.],
             [1., -1.],
@@ -288,12 +291,8 @@ mod tests {
         let vertex = face
             .exterior()
             .half_edges()
-            .flat_map(|half_edge| {
-                half_edge
-                    .boundary()
-                    .zip_ext(half_edge.surface_vertices().map(Clone::clone))
-            })
-            .find(|(_, surface_vertex)| {
+            .map(|half_edge| half_edge.start_vertex().clone())
+            .find(|surface_vertex| {
                 surface_vertex.position() == Point::from([-1., -1.])
             })
             .unwrap();
@@ -309,9 +308,10 @@ mod tests {
 
         let ray = HorizontalRayToTheRight::from([0., 0., 0.]);
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [-1., -1.],
             [1., -1.],
@@ -334,9 +334,10 @@ mod tests {
 
         let ray = HorizontalRayToTheRight::from([0., 0., 0.]);
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior.write().update_as_polygon_from_points([
             [-1., -1.],
             [1., -1.],
