@@ -3,12 +3,9 @@
 //! Algorithmic code is collected in this module, to keep other modules focused
 //! on their respective purpose.
 
-mod approx;
-mod sweep;
-mod triangulation;
-
-pub use self::{
-    approx::{CycleApprox, FaceApprox, Tolerance},
-    sweep::sweep_shape,
-    triangulation::triangulate,
-};
+pub mod approx;
+pub mod intersect;
+pub mod reverse;
+pub mod sweep;
+pub mod transform;
+pub mod triangulate;
