@@ -1,11 +1,15 @@
+use std::ops::Deref;
+
+use fj_interop::ext::ArrayExt;
 use fj_math::{Scalar, Vector};
 
 use crate::{
     algorithms::{reverse::Reverse, transform::TransformObject},
-    geometry::path::GlobalPath,
+    builder::{CycleBuilder, FaceBuilder},
+    geometry::curve::GlobalPath,
     insert::Insert,
     objects::{Face, Objects, Shell},
-    partial::{Partial, PartialObject, PartialShell},
+    partial::{Partial, PartialFace, PartialObject, PartialShell},
     services::Service,
     storage::Handle,
 };
@@ -47,35 +51,79 @@ impl Sweep for Handle<Face> {
                 self.clone().reverse(objects)
             }
         };
-        faces.push(bottom_face);
+        faces.push(bottom_face.clone());
 
-        let top_face = {
-            let mut face = self.clone().translate(path, objects);
+        let top_surface =
+            bottom_face.surface().clone().translate(path, objects);
+        let mut top_face = PartialFace {
+            surface: Partial::from(top_surface.clone()),
+            color: Some(self.color()),
+            ..PartialFace::default()
+        };
 
-            if is_negative_sweep {
-                face = face.reverse(objects);
+        for (i, cycle) in bottom_face.all_cycles().cloned().enumerate() {
+            let cycle = cycle.reverse(objects);
+
+            let mut top_cycle = if i == 0 {
+                top_face.exterior.clone()
+            } else {
+                top_face.add_interior()
             };
 
-            face
-        };
-        faces.push(top_face);
-
-        // Generate side faces
-        for cycle in self.all_cycles() {
-            for half_edge in cycle.half_edges() {
-                let half_edge = if is_negative_sweep {
-                    half_edge.clone().reverse(objects)
-                } else {
-                    half_edge.clone()
-                };
-
-                let face = (half_edge, self.color())
-                    .sweep_with_cache(path, cache, objects);
+            let mut original_edges = Vec::new();
+            let mut top_edges = Vec::new();
+            for half_edge in cycle.half_edges().cloned() {
+                let (face, top_edge) =
+                    (half_edge.clone(), self.surface().deref(), self.color())
+                        .sweep_with_cache(path, cache, objects);
 
                 faces.push(face);
+
+                original_edges.push(half_edge);
+                top_edges.push(Partial::from(top_edge));
+            }
+
+            top_cycle
+                .write()
+                .connect_to_closed_edges(top_edges, &top_surface.geometry());
+
+            for half_edge in &mut top_cycle.write().half_edges {
+                for (_, surface_vertex) in &mut half_edge.write().vertices {
+                    let mut surface_vertex = surface_vertex.write();
+                    let global_point =
+                        surface_vertex.global_form.read().position;
+
+                    if surface_vertex.position.is_none() {
+                        if let Some(global_point) = global_point {
+                            surface_vertex.position = Some(
+                                top_surface
+                                    .geometry()
+                                    .project_global_point(global_point),
+                            );
+                        }
+                    }
+                }
+            }
+
+            for (bottom, top) in original_edges
+                .into_iter()
+                .zip(top_cycle.write().half_edges.iter_mut())
+            {
+                top.write().curve = Some(bottom.curve().into());
+
+                let boundary = bottom.boundary();
+
+                for ((top, _), bottom) in
+                    top.write().vertices.each_mut_ext().zip_ext(boundary)
+                {
+                    *top = Some(bottom);
+                }
             }
         }
 
+        let top_face = top_face.build(objects).insert(objects);
+        faces.push(top_face);
+
         let faces = faces.into_iter().map(Partial::from).collect();
         PartialShell { faces }.build(objects).insert(objects)
     }
@@ -83,6 +131,8 @@ impl Sweep for Handle<Face> {
 
 #[cfg(test)]
 mod tests {
+    use std::ops::Deref;
+
     use fj_interop::{ext::SliceExt, mesh::Color};
 
     use crate::{
@@ -111,8 +161,7 @@ mod tests {
             let mut sketch = PartialSketch::default();
 
             let mut face = sketch.add_face();
-            face.write().exterior.write().surface =
-                Partial::from(surface.clone());
+            face.write().surface = Partial::from(surface.clone());
             face.write()
                 .exterior
                 .write()
@@ -125,23 +174,35 @@ mod tests {
             .insert(&mut services.objects)
             .sweep(UP, &mut services.objects);
 
-        let mut bottom = PartialFace::default();
-        bottom.exterior.write().surface = Partial::from(surface.clone());
-        bottom
-            .exterior
-            .write()
-            .update_as_polygon_from_points(TRIANGLE);
-        let bottom = bottom
-            .build(&mut services.objects)
-            .insert(&mut services.objects)
-            .reverse(&mut services.objects);
-        let mut top = PartialFace::default();
-        top.exterior.write().surface =
-            Partial::from(surface.translate(UP, &mut services.objects));
-        top.exterior.write().update_as_polygon_from_points(TRIANGLE);
-        let top = top
-            .build(&mut services.objects)
-            .insert(&mut services.objects);
+        let bottom = {
+            let mut bottom = PartialFace {
+                surface: Partial::from(surface.clone()),
+                ..Default::default()
+            };
+
+            bottom
+                .exterior
+                .write()
+                .update_as_polygon_from_points(TRIANGLE);
+
+            bottom
+                .build(&mut services.objects)
+                .insert(&mut services.objects)
+                .reverse(&mut services.objects)
+        };
+        let top = {
+            let surface = surface.clone().translate(UP, &mut services.objects);
+
+            let mut top = PartialFace {
+                surface: Partial::from(surface),
+                ..Default::default()
+            };
+
+            top.exterior.write().update_as_polygon_from_points(TRIANGLE);
+
+            top.build(&mut services.objects)
+                .insert(&mut services.objects)
+        };
 
         assert!(solid.find_face(&bottom).is_some());
         assert!(solid.find_face(&top).is_some());
@@ -150,16 +211,17 @@ mod tests {
         let side_faces = triangle.array_windows_ext().map(|&[a, b]| {
             let half_edge = {
                 let mut half_edge = PartialHalfEdge::default();
-                half_edge.update_as_line_segment_from_points(
-                    services.objects.surfaces.xy_plane(),
-                    [a, b],
-                );
+                half_edge.update_as_line_segment_from_points([a, b]);
+                half_edge
+                    .infer_vertex_positions_if_necessary(&surface.geometry());
 
                 half_edge
                     .build(&mut services.objects)
                     .insert(&mut services.objects)
             };
-            (half_edge, Color::default()).sweep(UP, &mut services.objects)
+            let (face, _) = (half_edge, surface.deref(), Color::default())
+                .sweep(UP, &mut services.objects);
+            face
         });
 
         assert!(side_faces
@@ -176,8 +238,7 @@ mod tests {
             let mut sketch = PartialSketch::default();
 
             let mut face = sketch.add_face();
-            face.write().exterior.write().surface =
-                Partial::from(surface.clone());
+            face.write().surface = Partial::from(surface.clone());
             face.write()
                 .exterior
                 .write()
@@ -190,24 +251,36 @@ mod tests {
             .insert(&mut services.objects)
             .sweep(DOWN, &mut services.objects);
 
-        let mut bottom = PartialFace::default();
-        bottom.exterior.write().surface = Partial::from(
-            surface.clone().translate(DOWN, &mut services.objects),
-        );
-        bottom
-            .exterior
-            .write()
-            .update_as_polygon_from_points(TRIANGLE);
-        let bottom = bottom
-            .build(&mut services.objects)
-            .insert(&mut services.objects)
-            .reverse(&mut services.objects);
-        let mut top = PartialFace::default();
-        top.exterior.write().surface = Partial::from(surface);
-        top.exterior.write().update_as_polygon_from_points(TRIANGLE);
-        let top = top
-            .build(&mut services.objects)
-            .insert(&mut services.objects);
+        let bottom = {
+            let surface =
+                surface.clone().translate(DOWN, &mut services.objects);
+
+            let mut bottom = PartialFace {
+                surface: Partial::from(surface),
+                ..Default::default()
+            };
+
+            bottom
+                .exterior
+                .write()
+                .update_as_polygon_from_points(TRIANGLE);
+
+            bottom
+                .build(&mut services.objects)
+                .insert(&mut services.objects)
+                .reverse(&mut services.objects)
+        };
+        let top = {
+            let mut top = PartialFace {
+                surface: Partial::from(surface.clone()),
+                ..Default::default()
+            };
+
+            top.exterior.write().update_as_polygon_from_points(TRIANGLE);
+
+            top.build(&mut services.objects)
+                .insert(&mut services.objects)
+        };
 
         assert!(solid.find_face(&bottom).is_some());
         assert!(solid.find_face(&top).is_some());
@@ -216,17 +289,18 @@ mod tests {
         let side_faces = triangle.array_windows_ext().map(|&[a, b]| {
             let half_edge = {
                 let mut half_edge = PartialHalfEdge::default();
-                half_edge.update_as_line_segment_from_points(
-                    services.objects.surfaces.xy_plane(),
-                    [a, b],
-                );
+                half_edge.update_as_line_segment_from_points([a, b]);
+                half_edge
+                    .infer_vertex_positions_if_necessary(&surface.geometry());
 
                 half_edge
                     .build(&mut services.objects)
                     .insert(&mut services.objects)
                     .reverse(&mut services.objects)
             };
-            (half_edge, Color::default()).sweep(DOWN, &mut services.objects)
+            let (face, _) = (half_edge, surface.deref(), Color::default())
+                .sweep(DOWN, &mut services.objects);
+            face
         });
 
         assert!(side_faces
