@@ -15,10 +15,9 @@ impl TransformObject for HalfEdge {
         objects: &mut Service<Objects>,
         cache: &mut TransformCache,
     ) -> Self {
-        let curve = self
-            .curve()
-            .clone()
-            .transform_with_cache(transform, objects, cache);
+        // Don't need to transform curve, as that's defined in surface
+        // coordinates.
+        let curve = self.curve();
         let boundary = self.boundary().zip_ext(self.surface_vertices()).map(
             |(point, surface_vertex)| {
                 let surface_vertex = surface_vertex
@@ -43,15 +42,11 @@ impl TransformObject for GlobalEdge {
         objects: &mut Service<Objects>,
         cache: &mut TransformCache,
     ) -> Self {
-        let curve = self
-            .curve()
-            .clone()
-            .transform_with_cache(transform, objects, cache);
         let vertices =
             self.vertices().access_in_normalized_order().map(|vertex| {
                 vertex.transform_with_cache(transform, objects, cache)
             });
 
-        Self::new(curve, vertices)
+        Self::new(vertices)
     }
 }
