@@ -96,9 +96,10 @@ mod tests {
         let c = [2., 2.];
         let d = [0., 1.];
 
-        let mut face = PartialFace::default();
-        face.exterior.write().surface =
-            Partial::from(services.objects.surfaces.xy_plane());
+        let mut face = PartialFace {
+            surface: Partial::from(services.objects.surfaces.xy_plane()),
+            ..Default::default()
+        };
         face.exterior
             .write()
             .update_as_polygon_from_points([a, b, c, d]);
@@ -136,8 +137,10 @@ mod tests {
         let h = [3., 1.];
 
         let surface = services.objects.surfaces.xy_plane();
-        let mut face = PartialFace::default();
-        face.exterior.write().surface = Partial::from(surface.clone());
+        let mut face = PartialFace {
+            surface: Partial::from(surface.clone()),
+            ..Default::default()
+        };
         face.exterior
             .write()
             .update_as_polygon_from_points([a, b, c, d]);
@@ -200,8 +203,10 @@ mod tests {
         let e = [0.0, 1.0];
 
         let surface = services.objects.surfaces.xy_plane();
-        let mut face = PartialFace::default();
-        face.exterior.write().surface = Partial::from(surface.clone());
+        let mut face = PartialFace {
+            surface: Partial::from(surface.clone()),
+            ..Default::default()
+        };
         face.exterior
             .write()
             .update_as_polygon_from_points([a, b, c, d, e]);
