@@ -1,8 +1,7 @@
-use fj_interop::ext::ArrayExt;
 use fj_math::Point;
 
 use crate::{
-    builder::SurfaceBuilder,
+    geometry::surface::SurfaceGeometry,
     objects::HalfEdge,
     partial::{Partial, PartialCycle},
 };
@@ -62,20 +61,25 @@ pub trait CycleBuilder {
     /// Will update each half-edge in the cycle to be a line segment.
     fn update_as_polygon(&mut self);
 
-    /// Update cycle as a triangle, from global (3D) points
+    /// Connect the cycles to the provided half-edges
     ///
-    /// Uses the three points to infer a plane that is used as the surface.
+    /// Assumes that the provided half-edges, once translated into local
+    /// equivalents of this cycle, form a cycle themselves.
     ///
-    /// # Implementation Note
-    ///
-    /// This method is probably just temporary, and will be generalized into a
-    /// "update as polygon from global points" method sooner or later. For now,
-    /// I didn't want to deal with the question of how to infer the surface, and
-    /// how to handle points that don't fit that surface.
-    fn update_as_triangle_from_global_points(
+    /// Returns the local equivalents of the provided half-edges.
+    fn connect_to_closed_edges<O>(
         &mut self,
-        points: [impl Into<Point<3>>; 3],
-    ) -> [Partial<HalfEdge>; 3];
+        edges: O,
+        surface: &SurfaceGeometry,
+    ) -> O::SameSize<Partial<HalfEdge>>
+    where
+        O: ObjectArgument<Partial<HalfEdge>>;
+
+    /// Infer the positions of all vertices, if necessary
+    fn infer_vertex_positions_if_necessary(
+        &mut self,
+        surface: &SurfaceGeometry,
+    );
 }
 
 impl CycleBuilder for PartialCycle {
@@ -120,7 +124,6 @@ impl CycleBuilder for PartialCycle {
 
             let [_, vertex] = &mut new_half_edge.vertices;
             vertex.1 = shared_surface_vertex;
-            new_half_edge.replace_surface(self.surface.clone());
             new_half_edge.infer_global_form();
         }
 
@@ -176,25 +179,29 @@ impl CycleBuilder for PartialCycle {
         }
     }
 
-    fn update_as_triangle_from_global_points(
+    fn connect_to_closed_edges<O>(
         &mut self,
-        points_global: [impl Into<Point<3>>; 3],
-    ) -> [Partial<HalfEdge>; 3] {
-        let points_global = points_global.map(Into::into);
+        edges: O,
+        surface: &SurfaceGeometry,
+    ) -> O::SameSize<Partial<HalfEdge>>
+    where
+        O: ObjectArgument<Partial<HalfEdge>>,
+    {
+        edges.map(|other| {
+            let mut this = self.add_half_edge();
+            this.write().update_from_other_edge(&other, surface);
+            this
+        })
+    }
 
-        let points_surface = self
-            .surface
-            .write()
-            .update_as_plane_from_points(points_global);
-
-        let half_edges = self.update_as_polygon_from_points(points_surface);
-
-        for (mut half_edge, point) in half_edges.clone().zip_ext(points_global)
-        {
-            let [vertex, _] = &mut half_edge.write().vertices;
-            vertex.1.write().global_form.write().position = Some(point);
+    fn infer_vertex_positions_if_necessary(
+        &mut self,
+        surface: &SurfaceGeometry,
+    ) {
+        for half_edge in &mut self.half_edges {
+            half_edge
+                .write()
+                .infer_vertex_positions_if_necessary(surface);
         }
-
-        half_edges
     }
 }
