@@ -1,4 +1,4 @@
 //! Types that are tied to objects, but aren't objects themselves
 
-pub mod path;
+pub mod curve;
 pub mod surface;
