@@ -4,8 +4,8 @@
 
 use crate::{
     objects::{
-        Curve, Cycle, Face, GlobalCurve, GlobalEdge, GlobalVertex, HalfEdge,
-        Objects, Shell, Sketch, Solid, Surface, SurfaceVertex,
+        Cycle, Face, GlobalEdge, GlobalVertex, HalfEdge, Objects, Shell,
+        Sketch, Solid, Surface, SurfaceVertex,
     },
     services::{Service, ServiceObjectsExt},
     storage::Handle,
@@ -34,10 +34,8 @@ macro_rules! impl_insert {
 }
 
 impl_insert!(
-    Curve, curves;
     Cycle, cycles;
     Face, faces;
-    GlobalCurve, global_curves;
     GlobalEdge, global_edges;
     GlobalVertex, global_vertices;
     HalfEdge, half_edges;
