@@ -3,11 +3,7 @@ use std::slice;
 use fj_interop::ext::SliceExt;
 use fj_math::{Scalar, Winding};
 
-use crate::{
-    geometry::path::SurfacePath,
-    objects::{HalfEdge, Surface},
-    storage::Handle,
-};
+use crate::{geometry::curve::Curve, objects::HalfEdge, storage::Handle};
 
 /// A cycle of connected half-edges
 #[derive(Clone, Debug, Eq, PartialEq, Hash, Ord, PartialOrd)]
@@ -36,17 +32,6 @@ impl Cycle {
         Self { half_edges }
     }
 
-    /// Access the surface that the cycle is in
-    pub fn surface(&self) -> &Handle<Surface> {
-        if let Some(half_edge) = self.half_edges.first() {
-            return half_edge.curve().surface();
-        }
-
-        unreachable!(
-            "Cycle has no half-edges, which the constructor should prevent."
-        )
-    }
-
     /// Access the half-edges that make up the cycle
     pub fn half_edges(&self) -> HalfEdgesOfCycle {
         self.half_edges.iter()
@@ -70,9 +55,9 @@ impl Cycle {
             let [a, b] = first.boundary();
             let edge_direction_positive = a < b;
 
-            let circle = match first.curve().path() {
-                SurfacePath::Circle(circle) => circle,
-                SurfacePath::Line(_) => unreachable!(
+            let circle = match first.curve() {
+                Curve::Circle(circle) => circle,
+                Curve::Line(_) => unreachable!(
                     "Invalid cycle: less than 3 edges, but not all are circles"
                 ),
             };
@@ -92,10 +77,8 @@ impl Cycle {
         let mut sum = Scalar::ZERO;
 
         for [a, b] in self.half_edges.as_slice().array_windows_ext() {
-            let [a, b] = [a, b].map(|half_edge| {
-                let [surface_vertex, _] = half_edge.surface_vertices();
-                surface_vertex.position()
-            });
+            let [a, b] =
+                [a, b].map(|half_edge| half_edge.start_vertex().position());
 
             sum += (b.u - a.u) * (b.v + a.v);
         }
