@@ -1,17 +1,51 @@
-use std::fmt;
-
 use fj_interop::ext::ArrayExt;
 use fj_math::Point;
 
 use crate::{
-    objects::{Curve, GlobalCurve, GlobalVertex, SurfaceVertex},
-    storage::{Handle, HandleWrapper},
+    geometry::curve::Curve,
+    objects::{GlobalVertex, SurfaceVertex},
+    storage::Handle,
 };
 
-/// A half-edge
+/// A directed edge, defined in a surface's 2D space
+///
+/// The concept of an "edge" in Fornjot is represented by two structs,
+/// `HalfEdge` and [`GlobalEdge`]. `HalfEdge` has two attributes that make it
+/// distinct from [`GlobalEdge`]:
+///
+/// - `HalfEdge` is directed, meaning it has a defined start and end vertex.
+/// - `HalfEdge` is defined in the 2-dimensional space of a surface.
+///
+/// When multiple faces, which are bound by edges, are combined to form a solid,
+/// the `HalfEdge`s that bound the face on the surface are then coincident with
+/// the `HalfEdge`s of other faces, where those faces touch. Those coincident
+/// `HalfEdge`s are different representations of the same edge. This edge is
+/// represented by an instance of [`GlobalEdge`].
+///
+/// There are some requirements that a `HalfEdge` needs to uphold to be valid:
+///
+/// 1. Coincident `HalfEdge`s *must* refer to the same [`GlobalEdge`].
+/// 2. `HalfEdge`s that are coincident, i.e. located in the same space, must
+///    always be congruent. This means they must coincide *exactly*. The overlap
+///    must be complete. None of the coincident `HalfEdge`s must overlap with
+///    just a section of another.
+///
+/// That second requirement means that a `HalfEdge` might need to be split into
+/// multiple smaller `HalfEdge`s that are each coincident with a `HalfEdge` in
+/// another face.
+///
+/// # Implementation Note
+///
+/// There is no validation code that verifies whether coincident `HalfEdge`s
+/// refer to the same [`GlobalEdge`] or not:
+/// <https://github.com/hannobraun/Fornjot/issues/1594>
+///
+/// Conversely, there is no validation code to verify that coincident
+/// `HalfEdge`s are congruent:
+/// <https://github.com/hannobraun/Fornjot/issues/1608>
 #[derive(Clone, Debug, Eq, PartialEq, Hash, Ord, PartialOrd)]
 pub struct HalfEdge {
-    curve: Handle<Curve>,
+    curve: Curve,
     boundary: [(Point<1>, Handle<SurfaceVertex>); 2],
     global_form: Handle<GlobalEdge>,
 }
@@ -19,7 +53,7 @@ pub struct HalfEdge {
 impl HalfEdge {
     /// Create an instance of `HalfEdge`
     pub fn new(
-        curve: Handle<Curve>,
+        curve: Curve,
         boundary: [(Point<1>, Handle<SurfaceVertex>); 2],
         global_form: Handle<GlobalEdge>,
     ) -> Self {
@@ -31,8 +65,8 @@ impl HalfEdge {
     }
 
     /// Access the curve that defines the half-edge's geometry
-    pub fn curve(&self) -> &Handle<Curve> {
-        &self.curve
+    pub fn curve(&self) -> Curve {
+        self.curve
     }
 
     /// Access the boundary points of the half-edge on the curve
@@ -40,6 +74,13 @@ impl HalfEdge {
         self.boundary.each_ref_ext().map(|&(point, _)| point)
     }
 
+    /// Access the vertex from where this half-edge starts
+    pub fn start_vertex(&self) -> &Handle<SurfaceVertex> {
+        let [vertex, _] =
+            self.boundary.each_ref_ext().map(|(_, vertex)| vertex);
+        vertex
+    }
+
     /// Access the surface vertices that bound the half-edge
     pub fn surface_vertices(&self) -> [&Handle<SurfaceVertex>; 2] {
         self.boundary
@@ -53,25 +94,17 @@ impl HalfEdge {
     }
 }
 
-impl fmt::Display for HalfEdge {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        let [a, b] = self.boundary();
-        write!(f, "edge from {a:?} to {b:?}")?;
-        write!(f, " on {:?}", self.curve().global_form())?;
-
-        Ok(())
-    }
-}
-
-/// An edge, defined in global (3D) coordinates
+/// An undirected edge, defined in global (3D) coordinates
 ///
-/// In contract to [`HalfEdge`], `GlobalEdge` is undirected, meaning it has no
+/// In contrast to [`HalfEdge`], `GlobalEdge` is undirected, meaning it has no
 /// defined direction, and its vertices have no defined order. This means it can
 /// be used to determine whether two [`HalfEdge`]s map to the same `GlobalEdge`,
 /// regardless of their direction.
+///
+/// See [`HalfEdge`]'s documentation for more information on the relationship
+/// between [`HalfEdge`] and `GlobalEdge`.
 #[derive(Clone, Debug, Eq, PartialEq, Hash, Ord, PartialOrd)]
 pub struct GlobalEdge {
-    curve: HandleWrapper<GlobalCurve>,
     vertices: VerticesInNormalizedOrder,
 }
 
@@ -81,19 +114,10 @@ impl GlobalEdge {
     /// The order of `vertices` is irrelevant. Two `GlobalEdge`s with the same
     /// `curve` and `vertices` will end up being equal, regardless of the order
     /// of `vertices` here.
-    pub fn new(
-        curve: impl Into<HandleWrapper<GlobalCurve>>,
-        vertices: [Handle<GlobalVertex>; 2],
-    ) -> Self {
-        let curve = curve.into();
+    pub fn new(vertices: [Handle<GlobalVertex>; 2]) -> Self {
         let (vertices, _) = VerticesInNormalizedOrder::new(vertices);
 
-        Self { curve, vertices }
-    }
-
-    /// Access the curve that defines the edge's geometry
-    pub fn curve(&self) -> &Handle<GlobalCurve> {
-        &self.curve
+        Self { vertices }
     }
 
     /// Access the vertices that bound the edge on the curve
@@ -158,14 +182,15 @@ mod tests {
 
         let a_to_b = {
             let mut half_edge = PartialHalfEdge::default();
-            half_edge
-                .update_as_line_segment_from_points(surface.clone(), [a, b]);
+            half_edge.update_as_line_segment_from_points([a, b]);
+            half_edge.infer_vertex_positions_if_necessary(&surface.geometry());
 
             half_edge.build(&mut services.objects)
         };
         let b_to_a = {
             let mut half_edge = PartialHalfEdge::default();
-            half_edge.update_as_line_segment_from_points(surface, [b, a]);
+            half_edge.update_as_line_segment_from_points([b, a]);
+            half_edge.infer_vertex_positions_if_necessary(&surface.geometry());
 
             half_edge.build(&mut services.objects)
         };
