@@ -1,12 +1,11 @@
 use fj_math::Point;
 
-use crate::{objects::Surface, storage::Handle};
+use crate::storage::Handle;
 
 /// A vertex, defined in surface (2D) coordinates
 #[derive(Clone, Debug, Eq, PartialEq, Hash, Ord, PartialOrd)]
 pub struct SurfaceVertex {
     position: Point<2>,
-    surface: Handle<Surface>,
     global_form: Handle<GlobalVertex>,
 }
 
@@ -14,13 +13,11 @@ impl SurfaceVertex {
     /// Construct a new instance of `SurfaceVertex`
     pub fn new(
         position: impl Into<Point<2>>,
-        surface: Handle<Surface>,
         global_form: Handle<GlobalVertex>,
     ) -> Self {
         let position = position.into();
         Self {
             position,
-            surface,
             global_form,
         }
     }
@@ -30,11 +27,6 @@ impl SurfaceVertex {
         self.position
     }
 
-    /// Access the surface that the vertex is defined in
-    pub fn surface(&self) -> &Handle<Surface> {
-        &self.surface
-    }
-
     /// Access the global form of the vertex
     pub fn global_form(&self) -> &Handle<GlobalVertex> {
         &self.global_form
