@@ -1,37 +1,24 @@
 use fj_math::Vector;
 
 use crate::{
-    geometry::{path::GlobalPath, surface::SurfaceGeometry},
+    geometry::{curve::GlobalPath, surface::SurfaceGeometry},
     storage::{Handle, Store},
 };
 
 use super::{
-    Curve, Cycle, Face, GlobalCurve, GlobalEdge, GlobalVertex, HalfEdge, Shell,
-    Sketch, Solid, Surface, SurfaceVertex,
+    Cycle, Face, GlobalEdge, GlobalVertex, HalfEdge, Shell, Sketch, Solid,
+    Surface, SurfaceVertex,
 };
 
 /// The available object stores
-///
-/// # Implementation Note
-///
-/// The intention is to eventually manage all objects in here. Making this
-/// happen is simply a case of putting in the required work. See [#1021].
-///
-/// [#1021]: https://github.com/hannobraun/Fornjot/issues/1021
 #[derive(Debug, Default)]
 pub struct Objects {
-    /// Store for [`Curve`]s
-    pub curves: Store<Curve>,
-
     /// Store for [`Cycle`]s
     pub cycles: Store<Cycle>,
 
     /// Store for [`Face`]s
     pub faces: Store<Face>,
 
-    /// Store for [`GlobalCurve`]s
-    pub global_curves: Store<GlobalCurve>,
-
     /// Store for [`GlobalEdge`]s
     pub global_edges: Store<GlobalEdge>,
 
@@ -80,7 +67,7 @@ impl Surfaces {
         self.store.reserve()
     }
 
-    /// Insert a [`Surface`] into the store
+    /// Insert an object into the store
     pub fn insert(&mut self, handle: Handle<Surface>, surface: Surface) {
         self.store.insert(handle, surface);
     }
