@@ -1,5 +1,5 @@
 use crate::{
-    objects::{Cycle, HalfEdge, Objects, Surface},
+    objects::{Cycle, HalfEdge, Objects},
     partial::{FullToPartialCache, Partial, PartialObject},
     services::Service,
 };
@@ -7,9 +7,6 @@ use crate::{
 /// A partial [`Cycle`]
 #[derive(Clone, Debug, Default)]
 pub struct PartialCycle {
-    /// The surface that the cycle is defined in
-    pub surface: Partial<Surface>,
-
     /// The half-edges that make up the cycle
     pub half_edges: Vec<Partial<HalfEdge>>,
 }
@@ -19,7 +16,6 @@ impl PartialObject for PartialCycle {
 
     fn from_full(cycle: &Self::Full, cache: &mut FullToPartialCache) -> Self {
         Self {
-            surface: Partial::from_full(cycle.surface().clone(), cache),
             half_edges: cycle
                 .half_edges()
                 .cloned()
