@@ -4,13 +4,8 @@ use fj_interop::ext::ArrayExt;
 use fj_math::Point;
 
 use crate::{
-    objects::{
-        Curve, GlobalCurve, GlobalEdge, GlobalVertex, HalfEdge, Objects,
-        SurfaceVertex,
-    },
-    partial::{
-        FullToPartialCache, Partial, PartialObject, PartialSurfaceVertex,
-    },
+    objects::{GlobalEdge, GlobalVertex, HalfEdge, Objects, SurfaceVertex},
+    partial::{FullToPartialCache, MaybeCurve, Partial, PartialObject},
     services::Service,
 };
 
@@ -18,7 +13,7 @@ use crate::{
 #[derive(Clone, Debug)]
 pub struct PartialHalfEdge {
     /// The curve that the half-edge is defined in
-    pub curve: Partial<Curve>,
+    pub curve: Option<MaybeCurve>,
 
     /// The vertices that bound the half-edge on the curve
     pub vertices: [(Option<Point<1>>, Partial<SurfaceVertex>); 2],
@@ -35,7 +30,7 @@ impl PartialObject for PartialHalfEdge {
         cache: &mut FullToPartialCache,
     ) -> Self {
         Self {
-            curve: Partial::from_full(half_edge.curve().clone(), cache),
+            curve: Some(half_edge.curve().into()),
             vertices: half_edge
                 .boundary()
                 .zip_ext(half_edge.surface_vertices())
@@ -53,42 +48,21 @@ impl PartialObject for PartialHalfEdge {
     }
 
     fn build(self, objects: &mut Service<Objects>) -> Self::Full {
-        let curve = self.curve.build(objects);
-        let vertices = self.vertices.map(|mut vertex| {
-            let position_surface = vertex.1.read().position;
-
-            // Infer surface position, if not available.
-            let position_surface = match position_surface {
-                Some(position_surface) => position_surface,
-                None => {
-                    let position_curve = vertex.0.expect(
-                        "Can't infer surface position without curve position",
-                    );
-                    let position_surface =
-                        curve.path().point_from_path_coords(position_curve);
-
-                    vertex.1.write().position = Some(position_surface);
-
-                    position_surface
-                }
-            };
-
-            // Infer global position, if not available.
-            let position_global = vertex.1.read().global_form.read().position;
-            if position_global.is_none() {
-                let surface = curve.surface().geometry();
-
-                let position_global =
-                    surface.point_from_surface_coords(position_surface);
-                vertex.1.write().global_form.write().position =
-                    Some(position_global);
+        let curve = match self.curve.expect("Need path to build curve") {
+            MaybeCurve::Defined(path) => path,
+            undefined => {
+                panic!(
+                    "Trying to build curve with undefined path: {undefined:?}"
+                )
             }
-
-            let position =
-                vertex.0.expect("Can't build `Vertex` without position");
+        };
+        let vertices = self.vertices.map(|vertex| {
+            let position_curve = vertex
+                .0
+                .expect("Can't build `HalfEdge` without boundary positions");
             let surface_form = vertex.1.build(objects);
 
-            (position, surface_form)
+            (position_curve, surface_form)
         });
         let global_form = self.global_form.build(objects);
 
@@ -98,19 +72,12 @@ impl PartialObject for PartialHalfEdge {
 
 impl Default for PartialHalfEdge {
     fn default() -> Self {
-        let curve = Partial::<Curve>::new();
+        let curve = None;
         let vertices = array::from_fn(|_| {
-            let surface = Partial::new();
-
-            let surface_form = Partial::from_partial(PartialSurfaceVertex {
-                surface,
-                ..Default::default()
-            });
-
+            let surface_form = Partial::default();
             (None, surface_form)
         });
 
-        let global_curve = curve.read().global_form.clone();
         let global_vertices = vertices.each_ref_ext().map(
             |vertex: &(Option<Point<1>>, Partial<SurfaceVertex>)| {
                 let surface_vertex = vertex.1.clone();
@@ -120,7 +87,6 @@ impl Default for PartialHalfEdge {
         );
 
         let global_form = Partial::from_partial(PartialGlobalEdge {
-            curve: global_curve,
             vertices: global_vertices,
         });
 
@@ -135,9 +101,6 @@ impl Default for PartialHalfEdge {
 /// A partial [`GlobalEdge`]
 #[derive(Clone, Debug, Default)]
 pub struct PartialGlobalEdge {
-    /// The curve that defines the edge's geometry
-    pub curve: Partial<GlobalCurve>,
-
     /// The vertices that bound the edge on the curve
     pub vertices: [Partial<GlobalVertex>; 2],
 }
@@ -150,7 +113,6 @@ impl PartialObject for PartialGlobalEdge {
         cache: &mut FullToPartialCache,
     ) -> Self {
         Self {
-            curve: Partial::from_full(global_edge.curve().clone(), cache),
             vertices: global_edge
                 .vertices()
                 .access_in_normalized_order()
@@ -159,9 +121,7 @@ impl PartialObject for PartialGlobalEdge {
     }
 
     fn build(self, objects: &mut Service<Objects>) -> Self::Full {
-        let curve = self.curve.build(objects);
         let vertices = self.vertices.map(|vertex| vertex.build(objects));
-
-        GlobalEdge::new(curve, vertices)
+        GlobalEdge::new(vertices)
     }
 }
