@@ -1,6 +1,5 @@
 //! Infrastructure for validating objects
 
-mod curve;
 mod cycle;
 mod edge;
 mod face;
@@ -12,7 +11,7 @@ mod vertex;
 
 pub use self::{
     cycle::CycleValidationError, edge::HalfEdgeValidationError,
-    face::FaceValidationError, vertex::SurfaceVertexValidationError,
+    face::FaceValidationError,
 };
 
 use std::convert::Infallible;
@@ -84,20 +83,16 @@ impl Default for ValidationConfig {
 #[derive(Clone, Debug, thiserror::Error)]
 pub enum ValidationError {
     /// `Cycle` validation error
-    #[error(transparent)]
+    #[error("`Cycle` validation error:\n{0}")]
     Cycle(#[from] CycleValidationError),
 
     /// `Face` validation error
-    #[error(transparent)]
+    #[error("`Face` validation error:\n{0}")]
     Face(#[from] Box<FaceValidationError>),
 
     /// `HalfEdge` validation error
-    #[error(transparent)]
+    #[error("`HalfEdge` validation error:\n{0}")]
     HalfEdge(#[from] Box<HalfEdgeValidationError>),
-
-    /// `SurfaceVertex` validation error
-    #[error(transparent)]
-    SurfaceVertex(#[from] Box<SurfaceVertexValidationError>),
 }
 
 impl From<Infallible> for ValidationError {
