@@ -35,7 +35,10 @@
 
 #![warn(missing_docs)]
 
+pub mod robust;
+
 mod aabb;
+mod arc;
 mod circle;
 mod coordinates;
 mod line;
@@ -50,6 +53,7 @@ mod vector;
 
 pub use self::{
     aabb::Aabb,
+    arc::Arc,
     circle::Circle,
     coordinates::{Uv, Xyz, T},
     line::Line,
