@@ -16,22 +16,39 @@
 //! [Fornjot]: https://www.fornjot.app/
 //! [Fornjot repository]: https://github.com/hannobraun/Fornjot
 
-#![deny(missing_docs)]
+#![warn(missing_docs)]
 
 pub mod syntax;
 
+#[doc(hidden)]
+pub mod abi;
+mod angle;
+mod group;
+pub mod models;
 mod shape_2d;
-mod shape_3d;
+mod sweep;
+mod transform;
+pub mod version;
 
-pub use self::{shape_2d::*, shape_3d::*};
+pub use self::{
+    angle::*, group::Group, shape_2d::*, sweep::Sweep, transform::Transform,
+};
+pub use fj_proc::*;
 
 /// A shape
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 #[repr(C)]
 pub enum Shape {
+    /// A group of two 3-dimensional shapes
+    Group(Box<Group>),
+
     /// A 2D shape
     Shape2d(Shape2d),
 
-    /// A 3D shape
-    Shape3d(Shape3d),
+    /// A sweep of 2-dimensional shape along the z-axis
+    Sweep(Sweep),
+
+    /// A transformed 3-dimensional shape
+    Transform(Box<Transform>),
 }
